# ------------------------------------------------------------------------------
#
#                        THE ECONOMICS OF WOMEN'S RIGHTS  
#
# ------------------------------------------------------------------------------
#
# by Michèle Tertilt, Matthias Doepke, Anne Hannusch and Laura Montenbruck
#
# This version: 2022-11-22
#
# This file generates Figure 3 in the paper
#
# Inpute file : IndicesOverTime.txt in subdirectory '../output/figures/'
#               generated by 2_DataForFigures.do in subdirectory '../code/'
#
# Output files: IndicesOverTime_JEEA.tex in subdirectory '../output/figures/'
#               IndicesOverTime_JEEA.pdf in subdirectory ../'output/figures/'
#          
# Notes:
# - To run the code, please adjust working directory in line 40
#
# ------------------------------------------------------------------------------ 

  rm(list=ls())
  library(reshape2)
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(stringr)
  library(tidyverse)
  library(tidyr)
  library(lubridate)  

  #---------------------------------
  # Figure 3
  #---------------------------------

  # Adjust working directory
  setwd("../ReplicationPackage/")
  
  # 1. Load data
  
  dat <- read.table("output/figures/IndicesOverTime.txt", 
                    sep="\t",
                    header = TRUE)

  dat$year = as.numeric(dat$year)
  
  df <- pivot_longer(dat,cols=c('Economic_rights', 'Political_rights', 'Labor_rights', 'Body_rights'),
                      names_to='law_type',
                      values_to='index')
  
  df$law_type <- factor(df$law_type,  levels=c("Economic_rights", "Political_rights", "Labor_rights", "Body_rights"))
  df <- subset(df, !is.na(law_type))
  df <- subset(df, !is.na(index)) 

  filename <- paste("output/figures/IndicesOverTime_JEEA",".tex",sep = "")
  
  tikzDevice::tikz(file=filename,height=3.5, width=6)  
  
  Figure3 <- ggplot(data=df, aes(x=year, y=index, group=law_type, colour = law_type)) + 
    geom_line(size=0.5) + 
    geom_point(aes(shape=law_type), size=1.75)+
    theme_bw()+
    xlab("Year") +
    scale_y_continuous(name="Women's Rights Index", breaks=c(30,40,50,60,70,80,90), limits=c(30,90)) +
    scale_color_manual(values=c('#c10534',
                                '#1a476f',
                                '#006000',
                                '#e37e00'),name="", labels = c("Economic Rights","Political Rights","Labor Rights","Body Rights")) +
    scale_shape_manual(values=c(8,15,17,19), name="", labels = c("Economic Rights","Political Rights","Labor Rights","Body Rights")) +
    scale_linetype_manual(values=c("longdash", "dotted", "dashed", "solid") , name="", labels = c("Economic Rights","Political Rights","Labor Rights","Body Rights")) +
    theme(legend.title = element_blank(),
          legend.text = element_text(size=12,margin = margin(r = 4, unit = "pt")),
          legend.position = "bottom",
          axis.text.x = element_text(size=12, vjust=-1),
          axis.text.y=element_text(size=12),
          axis.title.y=element_text(size=12),
          axis.title.x=element_text(size=12),
          panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"))+
    guides(col = guide_legend(nrow = 1))
  
  ggsave("output/figures/IndicesOverTime_JEEA.pdf",plot=Figure3)      
  
  print(Figure3)
  dev.off()  
  
  #-------------
  # end of file
  #-------------
